pro kp_access, date, kpindex, kpdata, he=he, kpfiles=kpfiles, $
    nodisplay=nodisplay, qdebug=qdebug
;+
; NAME: kp_access
; PURPOSE: read KP low-res data from the ISAS database for a given date
; CALLING SEQUENCE: kp_access, date, kpindex, kpdata
; INPUT PARAMETERS: date  (such as '15-JAN-92')
; OUTPUT PARAMETERS: kpindex, kpdata
; OPTIONAL KEYWORDS:  nodisplay: nodisplay to avoid display
;                     he: select He 10830 image instead of magnetogram
; MINOR DETAILS:  There are weird files in the database.  Some efforts 
;                are made not to access those.
;
; HISTORY:        15-Mar-01  written by NVN for Steve Kahler
;                  5-May-01  ys_contribbed by HSH after Kahler tests
;-
spawn,'pwd',pwd0

fnam3='gkm'
if keyword_set(he) then fnam3='gki'

extim=anytim2ex(date)
ymd=strmid(string(extim(6),format='(i4.4)'),2,2)+ $
   string(extim(5),format='(i2.2)')+string(extim(4),format='(i2.2)')
wid=anytim2weekid(date,/str)

infil=find_file('$gdb/gbo'+wid(0)+'/'+fnam3+ymd+'*') 
sz=size(infil)
if sz(0) eq 0 then begin
   print,'No file was found for that day.'
   return
endif 

; Occasionally we seem to have garbage files for unknown reasons.
; the following is to avoid the second of the following files.
; /db_isass5/ydb/gbo/gbo00_05a/gkm000123.1630
; /db_isass5/ydb/gbo/gbo00_05a/gkm00012316.1630
validf=intarr(sz(1))
for i=0,sz(1)-1 do validf(i)=strpos(infil(i),'.')- $
   strpos(infil(i),fnam3)
svalid=where(validf eq 9, nvalid)
if nvalid lt 1 then begin
   print,'No valid file was found for that day.'
   return
endif 
infil=infil(svalid)


kpinfil=infil
nf=n_elements(kpinfil)
print,nf,' files found.  They are:'
print,kpinfil
kpfiles=kpinfil

if sz(1) gt 1 then begin ; to determine which file is real (not via NOAA)
   fs=file_size(kpinfil)
   jj=where(fs eq max(fs))
   kpinfil=kpinfil(jj(0))
endif
kpinfil=kpinfil(0)

print,'copying the largest file to /tmp'
spawn,'cp '+kpinfil+' /tmp/.'
infil=find_file('/tmp/'+fnam3+ymd+'*')
infil=infil(0)
if strmid(infil,strlen(infil)-1,1) eq 'Z' then begin
   com='uncompress '+infil(0)
   spawn,com
endif

kpinfil=find_file('/tmp/'+fnam3+ymd+'*')
kpinfil=kpinfil(0)

tim0=fix(strmid(kpinfil,strlen(kpinfil)-4,2))
; print,tim0,kpinfil
tim1=fix(strmid(kpinfil,strlen(kpinfil)-2,2))
tim2=0
tim3=0
tim4=fix(strmid(kpinfil,strlen(kpinfil)-7,2))
tim5=fix(strmid(kpinfil,strlen(kpinfil)-9,2))
tim6=fix(strmid(kpinfil,strlen(kpinfil)-11,2))
if tim6 ge 90 and tim6 le 99 then tim6=tim6+1900
if tim6 lt 90 then tim6=tim6+2000
timfil=fmt_tim(anytim2ints([tim0,tim1,tim2,tim3,tim4,tim5,tim6]))


cd,'$SSW/optical/nso/idl'
resolve_routine,'read_nso'
cd,pwd0(0)

read_nso,kpinfil,kpindex,kpdata
maxdata=max(kpdata)
mindata=min(kpdata)
if mindata lt 0 and maxdata lt 0 then begin
   print,'data seem outrageous, both min and max values negative.'
   com2='rm -f '+kpinfil
   print,'deleting '+kpinfil
   spawn,com2
   return
endif


timd=kpindex.date_obs
dtim0=fix(strmid(timd,strlen(timd)-13,2))
dtim1=fix(strmid(timd,strlen(timd)-10,2))
dtim2=fix(strmid(timd,strlen(timd)-7,2))
dtim3=0
dtim4=fix(strmid(timd,8,2))
dtim5=fix(strmid(timd,5,2))
dtim6=fix(strmid(timd,0,4))
dtim=fmt_tim(anytim2ints([dtim0,dtim1,dtim2,dtim3,dtim4,dtim5,dtim6]))

deltat0=abs(int2secarr(dtim,date)/86400.)
deltat1=abs(int2secarr(timfil,date)/86400.)
time=dtim
if deltat1 lt deltat0 then time=timfil

if mindata eq 0 and maxdata le 255 then begin ; looks like bytscl'ed
   print,'This file seems to come from NOAA, already byte scaled.'
   if not keyword_set(nodisplay) then begin
      wdef,/free
      tv,bytscl(kpdata)
   endif
   com2='rm -f '+kpinfil
   print,'deleting '+kpinfil
   spawn,com2
   return
endif
   
minsc=-100 & maxsc=100
if keyword_set(he) then begin 
   minsc=-180
   maxsc=80
endif


if not keyword_set(nodisplay) then begin
   wdef,/free
   tv,bytscl(kpdata,minsc,maxsc)
   xyouts,10,10,time,chars=1.5,/dev
endif

com2='rm -f '+kpinfil
print,'deleting '+kpinfil
spawn,com2

if keyword_set(qdebug) then stop
return

end












